package com.srs.comprehensive.mapper;

import java.util.List;
import com.srs.comprehensive.domain.CphDormitoryGood;
import org.apache.ibatis.annotations.Mapper;

/**
 * 优秀宿舍Mapper接口
 * 
 * @author srs
 * @date 2023-07-04
 */
@Mapper
public interface CphDormitoryGoodMapper 
{
    /**
     * 查询优秀宿舍
     * 
     * @param id 优秀宿舍主键
     * @return 优秀宿舍
     */
    public CphDormitoryGood selectCphDormitoryGoodById(Long id);

    /**
     * 查询优秀宿舍列表
     * 
     * @param cphDormitoryGood 优秀宿舍
     * @return 优秀宿舍集合
     */
    public List<CphDormitoryGood> selectCphDormitoryGoodList(CphDormitoryGood cphDormitoryGood);

    /**
     * 新增优秀宿舍
     * 
     * @param cphDormitoryGood 优秀宿舍
     * @return 结果
     */
    public int insertCphDormitoryGood(CphDormitoryGood cphDormitoryGood);

    /**
     * 修改优秀宿舍
     * 
     * @param cphDormitoryGood 优秀宿舍
     * @return 结果
     */
    public int updateCphDormitoryGood(CphDormitoryGood cphDormitoryGood);

    /**
     * 删除优秀宿舍
     * 
     * @param id 优秀宿舍主键
     * @return 结果
     */
    public int deleteCphDormitoryGoodById(Long id);

    /**
     * 批量删除优秀宿舍
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCphDormitoryGoodByIds(Long[] ids);
}
